package com.ruoyi.project.patrol.dev.service;

import java.util.List;
import com.ruoyi.project.patrol.dev.domain.TDevTester;

/**
 * 检测仪Service接口
 * 
 * @author admin
 * @date 2023-11-03
 */
public interface ITDevTesterService 
{
    /**
     * 查询检测仪
     * 
     * @param id 检测仪主键
     * @return 检测仪
     */
    public TDevTester selectTDevTesterById(Long id);

    /**
     * 查询检测仪列表
     * 
     * @param tDevTester 检测仪
     * @return 检测仪集合
     */
    public List<TDevTester> selectTDevTesterList(TDevTester tDevTester);

    /**
     * 新增检测仪
     * 
     * @param tDevTester 检测仪
     * @return 结果
     */
    public int insertTDevTester(TDevTester tDevTester);

    /**
     * 修改检测仪
     * 
     * @param tDevTester 检测仪
     * @return 结果
     */
    public int updateTDevTester(TDevTester tDevTester);

    /**
     * 批量删除检测仪
     * 
     * @param ids 需要删除的检测仪主键集合
     * @return 结果
     */
    public int deleteTDevTesterByIds(Long[] ids);

    /**
     * 删除检测仪信息
     * 
     * @param id 检测仪主键
     * @return 结果
     */
    public int deleteTDevTesterById(Long id);
}
